==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/HelmMappingRuleProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Helm mapping rule profile
 * @property helmPackageVersion Helm package version.
 * @property options The helm deployment options
 * @property releaseName Helm release name.
 * @property releaseNamespace Helm release namespace.
 * @property values Helm release values.
 */
public data class HelmMappingRuleProfileArgs(
    public val helmPackageVersion: Output<String>? = null,
    public val options: Output<HelmMappingRuleProfileOptionsArgs>? = null,
    public val releaseName: Output<String>? = null,
    public val releaseNamespace: Output<String>? = null,
    public val values: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs.builder()
            .helmPackageVersion(helmPackageVersion?.applyValue({ args0 -> args0 }))
            .options(options?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .releaseName(releaseName?.applyValue({ args0 -> args0 }))
            .releaseNamespace(releaseNamespace?.applyValue({ args0 -> args0 }))
            .values(values?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HelmMappingRuleProfileArgs].
 */
@PulumiTagMarker
public class HelmMappingRuleProfileArgsBuilder internal constructor() {
    private var helmPackageVersion: Output<String>? = null

    private var options: Output<HelmMappingRuleProfileOptionsArgs>? = null

    private var releaseName: Output<String>? = null

    private var releaseNamespace: Output<String>? = null

    private var values: Output<String>? = null

    /**
     * @param value Helm package version.
     */
    @JvmName("ruollefsraooyfwo")
    public suspend fun helmPackageVersion(`value`: Output<String>) {
        this.helmPackageVersion = value
    }

    /**
     * @param value The helm deployment options
     */
    @JvmName("ugrhjytsaxcbbmij")
    public suspend fun options(`value`: Output<HelmMappingRuleProfileOptionsArgs>) {
        this.options = value
    }

    /**
     * @param value Helm release name.
     */
    @JvmName("pqmccjgptfwylwhe")
    public suspend fun releaseName(`value`: Output<String>) {
        this.releaseName = value
    }

    /**
     * @param value Helm release namespace.
     */
    @JvmName("nmvbqmugjiqkviks")
    public suspend fun releaseNamespace(`value`: Output<String>) {
        this.releaseNamespace = value
    }

    /**
     * @param value Helm release values.
     */
    @JvmName("lyddbugurtatyaaw")
    public suspend fun values(`value`: Output<String>) {
        this.values = value
    }

    /**
     * @param value Helm package version.
     */
    @JvmName("tnukmwsfqabghlaw")
    public suspend fun helmPackageVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.helmPackageVersion = mapped
    }

    /**
     * @param value The helm deployment options
     */
    @JvmName("ykmgusdqpqklpnvx")
    public suspend fun options(`value`: HelmMappingRuleProfileOptionsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.options = mapped
    }

    /**
     * @param argument The helm deployment options
     */
    @JvmName("plioxnojyfmkkgtk")
    public suspend
    fun options(argument: suspend HelmMappingRuleProfileOptionsArgsBuilder.() -> Unit) {
        val toBeMapped = HelmMappingRuleProfileOptionsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.options = mapped
    }

    /**
     * @param value Helm release name.
     */
    @JvmName("rdcrfhrhwsehoiel")
    public suspend fun releaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.releaseName = mapped
    }

    /**
     * @param value Helm release namespace.
     */
    @JvmName("jxwaujpakkjwolpr")
    public suspend fun releaseNamespace(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.releaseNamespace = mapped
    }

    /**
     * @param value Helm release values.
     */
    @JvmName("tarvxipbrjjfabpn")
    public suspend fun values(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): HelmMappingRuleProfileArgs = HelmMappingRuleProfileArgs(
        helmPackageVersion = helmPackageVersion,
        options = options,
        releaseName = releaseName,
        releaseNamespace = releaseNamespace,
        values = values,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/HelmMappingRuleProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Helm mapping rule profile
 * @property helmPackageVersion Helm package version.
 * @property options The helm deployment options
 * @property releaseName Helm release name.
 * @property releaseNamespace Helm release namespace.
 * @property values Helm release values.
 */
public data class HelmMappingRuleProfileArgs(
    public val helmPackageVersion: Output<String>? = null,
    public val options: Output<HelmMappingRuleProfileOptionsArgs>? = null,
    public val releaseName: Output<String>? = null,
    public val releaseNamespace: Output<String>? = null,
    public val values: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.HelmMappingRuleProfileArgs.builder()
            .helmPackageVersion(helmPackageVersion?.applyValue({ args0 -> args0 }))
            .options(options?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .releaseName(releaseName?.applyValue({ args0 -> args0 }))
            .releaseNamespace(releaseNamespace?.applyValue({ args0 -> args0 }))
            .values(values?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HelmMappingRuleProfileArgs].
 */
@PulumiTagMarker
public class HelmMappingRuleProfileArgsBuilder internal constructor() {
    private var helmPackageVersion: Output<String>? = null

    private var options: Output<HelmMappingRuleProfileOptionsArgs>? = null

    private var releaseName: Output<String>? = null

    private var releaseNamespace: Output<String>? = null

    private var values: Output<String>? = null

    /**
     * @param value Helm package version.
     */
    @JvmName("jprisgqgfbwifwtk")
    public suspend fun helmPackageVersion(`value`: Output<String>) {
        this.helmPackageVersion = value
    }

    /**
     * @param value The helm deployment options
     */
    @JvmName("inbydrffxhruxnys")
    public suspend fun options(`value`: Output<HelmMappingRuleProfileOptionsArgs>) {
        this.options = value
    }

    /**
     * @param value Helm release name.
     */
    @JvmName("brytmiedsltewlql")
    public suspend fun releaseName(`value`: Output<String>) {
        this.releaseName = value
    }

    /**
     * @param value Helm release namespace.
     */
    @JvmName("fskwcsqtqosmgnek")
    public suspend fun releaseNamespace(`value`: Output<String>) {
        this.releaseNamespace = value
    }

    /**
     * @param value Helm release values.
     */
    @JvmName("ntqqxsafanhfrkvb")
    public suspend fun values(`value`: Output<String>) {
        this.values = value
    }

    /**
     * @param value Helm package version.
     */
    @JvmName("qaxlughbnkoqetsu")
    public suspend fun helmPackageVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.helmPackageVersion = mapped
    }

    /**
     * @param value The helm deployment options
     */
    @JvmName("kisamgrutfiqqnrj")
    public suspend fun options(`value`: HelmMappingRuleProfileOptionsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.options = mapped
    }

    /**
     * @param argument The helm deployment options
     */
    @JvmName("fdtaifyaatshgifl")
    public suspend
    fun options(argument: suspend HelmMappingRuleProfileOptionsArgsBuilder.() -> Unit) {
        val toBeMapped = HelmMappingRuleProfileOptionsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.options = mapped
    }

    /**
     * @param value Helm release name.
     */
    @JvmName("kwwxtlkipixmwqgs")
    public suspend fun releaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.releaseName = mapped
    }

    /**
     * @param value Helm release namespace.
     */
    @JvmName("blywbyswvsdgrmpi")
    public suspend fun releaseNamespace(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.releaseNamespace = mapped
    }

    /**
     * @param value Helm release values.
     */
    @JvmName("kwttpthyooqagekr")
    public suspend fun values(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): HelmMappingRuleProfileArgs = HelmMappingRuleProfileArgs(
        helmPackageVersion = helmPackageVersion,
        options = options,
        releaseName = releaseName,
        releaseNamespace = releaseNamespace,
        values = values,
    )
}
